summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--sleekxmpp/clientxmpp.py9
1 files changed, 6 insertions, 3 deletions
diff --git a/sleekxmpp/clientxmpp.py b/sleekxmpp/clientxmpp.py
index 32795e4b..734c9a14 100644
--- a/sleekxmpp/clientxmpp.py
+++ b/sleekxmpp/clientxmpp.py
@@ -139,7 +139,7 @@ class ClientXMPP(BaseXMPP):
log.debug("Session start has taken more than 15 seconds")
self.disconnect(reconnect=self.auto_reconnect)
- def connect(self, address=tuple()):
+ def connect(self, address=tuple(), reattempt=True):
"""
Connect to the XMPP server.
@@ -148,7 +148,9 @@ class ClientXMPP(BaseXMPP):
will be used.
Arguments:
- address -- A tuple containing the server's host and port.
+ address -- A tuple containing the server's host and port.
+ reattempt -- If True, reattempt the connection if an
+ error occurs.
"""
self.session_started_event.clear()
if not address or len(address) < 2:
@@ -190,7 +192,8 @@ class ClientXMPP(BaseXMPP):
# If all else fails, use the server from the JID.
address = (self.boundjid.host, 5222)
- return XMLStream.connect(self, address[0], address[1], use_tls=True)
+ return XMLStream.connect(self, address[0], address[1],
+ use_tls=True, reattempt=reattempt)
def register_feature(self, mask, pointer, breaker=False):
"""